@@ -12,7 +12,7 @@ use self::props::*;
 
 /// Current Unicode version.
 pub const UNICODE_VERSION: UnicodeVersion = UnicodeVersion {
-    major: 13,
+    major: 14,
     minor: 0,
     update: 0,
 };
@@ -82,47 +82,93 @@ pub trait Ucd {
     /// Get the Unicode Name(na) property. If there is no Name property, then
     /// returns empty string.
     fn na(&self) -> String;
+    /// Get the Unicode Bidi_Class(bc) property.
     fn bc(&self) -> Bc;
+    /// Get the Unicode Canonical_Combining_Class(ccc) property.
     fn ccc(&self) -> Ccc;
+    /// Get the Unicode Decomposition_Type(dt) property.
     fn dt(&self) -> Dt;
+    /// Get the Unicode General_Category(gc) property.
     fn gc(&self) -> Gc;
+    /// Get the Unicode Grapheme_Cluster_Break(GCB) property.
     fn gcb(&self) -> Gcb;
+    /// Get the Unicode Word_Break(WB) property.
+    fn wb(&self) -> Wb;
+    /// Get the Unicode Hangul_Syllable_Type(hst) property.
     fn hst(&self) -> Hst;
+    /// Get the Unicode White_Space(WSpace) property.
     fn wspace(&self) -> bool;
+    /// Get the Unicode Bidi_Control(Bidi_C) property.
     fn bidi_c(&self) -> bool;
+    /// Get the Unicode Join_Control(Join_C) property.
     fn join_c(&self) -> bool;
+    /// Get the Unicode Dash(Dash) property.
     fn dash(&self) -> bool;
+    /// Get the Unicode Hyphen(Hyphen) property.
     fn hyphen(&self) -> bool;
+    /// Get the Unicode Quotation_Mark(QMark) property.
     fn qmark(&self) -> bool;
+    /// Get the Unicode Terminal_Punctuation(Term) property.
     fn term(&self) -> bool;
+    /// Get the Unicode Other_Math(OMath) property.
     fn omath(&self) -> bool;
+    /// Get the Unicode Hex_Digit(Hex) property.
     fn hex(&self) -> bool;
+    /// Get the Unicode ASCII_Hex_Digit(AHex) property.
     fn ahex(&self) -> bool;
+    /// Get the Unicode Other_Alphabetic(OAlpha) property.
     fn oalpha(&self) -> bool;
+    /// Get the Unicode Ideographic(Ideo) property.
     fn ideo(&self) -> bool;
+    /// Get the Unicode Diacritic(Dia) property.
     fn dia(&self) -> bool;
+    /// Get the Unicode Extender(Ext) property.
     fn ext(&self) -> bool;
+    /// Get the Unicode Other_Lowercase(OLower) property.
     fn olower(&self) -> bool;
+    /// Get the Unicode Other_Uppercase(OUpper) property.
     fn oupper(&self) -> bool;
+    /// Get the Unicode Noncharacter_Code_Point(NChar) property.
     fn nchar(&self) -> bool;
+    /// Get the Unicode Other_Grapheme_Extend(OGr_Ext) property.
     fn ogr_ext(&self) -> bool;
+    /// Get the Unicode IDS_Binary_Operator(IDSB) property.
     fn idsb(&self) -> bool;
+    /// Get the Unicode IDS_Trinary_Operator(IDST) property.
     fn idst(&self) -> bool;
+    /// Get the Unicode Radical(Radical) property.
     fn radical(&self) -> bool;
+    /// Get the Unicode Unified_Ideograph(UIdeo) property.
     fn uideo(&self) -> bool;
+    /// Get the Unicode Other_Default_Ignorable_Code_Point(ODI) property.
     fn odi(&self) -> bool;
+    /// Get the Unicode Deprecated(Dep) property.
     fn dep(&self) -> bool;
+    /// Get the Unicode Soft_Dotted(SD) property.
     fn sd(&self) -> bool;
+    /// Get the Unicode Logical_Order_Exception(LOE) property.
     fn loe(&self) -> bool;
+    /// Get the Unicode Other_ID_Start(OIDS) property.
     fn oids(&self) -> bool;
+    /// Get the Unicode Other_ID_Continue(OIDC) property.
     fn oidc(&self) -> bool;
+    /// Get the Unicode Sentence_Terminal(STerm) property.
     fn sterm(&self) -> bool;
+    /// Get the Unicode Variation_Selector(VS) property.
     fn vs(&self) -> bool;
+    /// Get the Unicode Pattern_White_Space(Pat_WS) property.
     fn pat_ws(&self) -> bool;
+    /// Get the Unicode Pattern_Syntax(Pat_Syn) property.
     fn pat_syn(&self) -> bool;
+    /// Get the Unicode Prepended_Concatenation_Mark(PCM) property.
     fn pcm(&self) -> bool;
+    /// Get the Unicode Regional_Indicator(RI) property.
     fn ri(&self) -> bool;
+    /// Get the Unicode Composition_Exclusion(CE) property.
     fn ce(&self) -> bool;
+    /// Get the Unicode Case_Ignorable(CI) property.
+    fn ci(&self) -> bool;
+    /// Get the Unicode Full_Composition_Exclusion(Comp_Ex) property.
     fn comp_ex(&self) -> bool;
 
     /// Get the Unicode Block(blk) property.
@@ -132,17 +178,32 @@ pub trait Ucd {
     /// Get the Unicode Age(age) property.
     fn age(&self) -> Age;
 
+    /// Get the Unicode Math(Math) property.
     fn math(&self) -> bool;
+    /// Get the Unicode Alphabetic(Alpha) property.
     fn alpha(&self) -> bool;
+    /// Get the Unicode Lowercase(Lower) property.
     fn lower(&self) -> bool;
+    /// Get the Unicode Uppercase(Upper) property.
     fn upper(&self) -> bool;
+    /// Get the Unicode Cased(Cased) property.
     fn cased(&self) -> bool;
+    /// Get the Unicode Default_Ignorable_Code_Point(DI) property.
+    fn di(&self) -> bool;
+    /// Get the Unicode Grapheme_Extend(Gr_Ext) property.
+    fn gr_ext(&self) -> bool;
 
+    /// Get the Unicode Emoji(Emoji) property.
     fn emoji(&self) -> bool;
+    /// Get the Unicode Emoji_Presentation(EPres) property.
     fn epres(&self) -> bool;
+    /// Get the Unicode Emoji_Modifier(EMod) property.
     fn emod(&self) -> bool;
+    /// Get the Unicode Emoji_Modifier_Base(EBase) property.
     fn ebase(&self) -> bool;
+    /// Get the Unicode Emoji_Component(EComp) property.
     fn ecomp(&self) -> bool;
+    /// Get the Unicode Extended_Pictographic(ExtPict) property.
     fn ext_pict(&self) -> bool;
 }
 
@@ -175,6 +236,10 @@ impl Ucd for CodePoint {
         ucd::gcb::gcb(self.code_point)
     }
 
+    fn wb(&self) -> Wb {
+        ucd::wb::wb(self.code_point)
+    }
+
     fn hst(&self) -> Hst {
         ucd::hst::hst(self.code_point)
     }
@@ -319,6 +384,10 @@ impl Ucd for CodePoint {
         ucd::ce::ce(self.code_point)
     }
 
+    fn ci(&self) -> bool {
+        ucd::derived_props::ci(self.code_point)
+    }
+
     fn comp_ex(&self) -> bool {
         ucd::normalization_props::comp_ex(self.code_point)
     }
@@ -355,6 +424,14 @@ impl Ucd for CodePoint {
         ucd::derived_props::cased(self.code_point)
     }
 
+    fn di(&self) -> bool {
+        ucd::derived_props::di(self.code_point)
+    }
+
+    fn gr_ext(&self) -> bool {
+        ucd::derived_props::gr_ext(self.code_point)
+    }
+
     fn emoji(&self) -> bool {
         ucd::emoji_props::emoji(self.code_point)
     }
@@ -409,6 +486,10 @@ impl Ucd for char {
         ucd::gcb::gcb(*self as u32)
     }
 
+    fn wb(&self) -> Wb {
+        ucd::wb::wb(*self as u32)
+    }
+
     fn hst(&self) -> Hst {
         ucd::hst::hst(*self as u32)
     }
@@ -553,6 +634,10 @@ impl Ucd for char {
         ucd::ce::ce(*self as u32)
     }
 
+    fn ci(&self) -> bool {
+        ucd::derived_props::ci(*self as u32)
+    }
+
     fn comp_ex(&self) -> bool {
         ucd::normalization_props::comp_ex(*self as u32)
     }
@@ -589,6 +674,14 @@ impl Ucd for char {
         ucd::derived_props::cased(*self as u32)
     }
 
+    fn di(&self) -> bool {
+        ucd::derived_props::di(*self as u32)
+    }
+
+    fn gr_ext(&self) -> bool {
+        ucd::derived_props::gr_ext(*self as u32)
+    }
+
     fn emoji(&self) -> bool {
         ucd::emoji_props::emoji(*self as u32)
     }
