@@ -274,6 +274,7 @@ pub enum Blk {
     AncientSymbols,
     Arabic,
     ArabicExtA,
+    ArabicExtB,
     ArabicMath,
     ArabicPfA,
     ArabicPfB,
@@ -330,6 +331,7 @@ pub enum Blk {
     CuneiformNumbers,
     CurrencySymbols,
     CypriotSyllabary,
+    CyproMinoan,
     Cyrillic,
     CyrillicExtA,
     CyrillicExtB,
@@ -360,6 +362,7 @@ pub enum Blk {
     Ethiopic,
     EthiopicExt,
     EthiopicExtA,
+    EthiopicExtB,
     EthiopicSup,
     GeometricShapes,
     GeometricShapesExt,
@@ -399,6 +402,7 @@ pub enum Blk {
     Javanese,
     Kaithi,
     KanaExtA,
+    KanaExtB,
     KanaSup,
     Kanbun,
     Kangxi,
@@ -420,6 +424,8 @@ pub enum Blk {
     LatinExtC,
     LatinExtD,
     LatinExtE,
+    LatinExtF,
+    LatinExtG,
     Lepcha,
     LetterlikeSymbols,
     Limbu,
@@ -486,6 +492,7 @@ pub enum Blk {
     OldSogdian,
     OldSouthArabian,
     OldTurkic,
+    OldUyghur,
     Oriya,
     OrnamentalDingbats,
     Osage,
@@ -547,6 +554,7 @@ pub enum Blk {
     Takri,
     Tamil,
     TamilSup,
+    Tangsa,
     Tangut,
     TangutComponents,
     TangutSup,
@@ -556,13 +564,16 @@ pub enum Blk {
     Tibetan,
     Tifinagh,
     Tirhuta,
+    Toto,
     TransportAndMap,
     Ucas,
     UcasExt,
+    UcasExtA,
     Ugaritic,
     Vai,
     VedicExt,
     VerticalForms,
+    Vithkuqi,
     Vs,
     VsSup,
     Wancho,
@@ -572,6 +583,7 @@ pub enum Blk {
     YiSyllables,
     Yijing,
     ZanabazarSquare,
+    ZnamennyMusic,
 }
 
 impl UnicodeProperty for Blk {
@@ -610,6 +622,7 @@ pub enum Sc {
     Cher,
     Chrs,
     Copt,
+    Cpmn,
     Cprt,
     Cyrl,
     Deva,
@@ -689,6 +702,7 @@ pub enum Sc {
     Orya,
     Osge,
     Osma,
+    Ougr,
     Palm,
     Pauc,
     Perm,
@@ -731,8 +745,11 @@ pub enum Sc {
     Thai,
     Tibt,
     Tirh,
+    Tnsa,
+    Toto,
     Ugar,
     Vaii,
+    Vith,
     Wara,
     Wcho,
     Xpeo,
@@ -777,6 +794,7 @@ pub enum Age {
     V12_0,
     V12_1,
     V13_0,
+    V14_0,
     NA,
 }
 
@@ -785,3 +803,37 @@ impl UnicodeProperty for Age {
         property_names::age_name(*self)
     }
 }
+
+/// Unicode property Word_Break(WB).
+#[derive(Debug, PartialEq, Clone, Copy)]
+pub enum Wb {
+    CR,     // CR
+    DQ,     // Double_Quote
+    EB,     // E_Base
+    EBG,    // E_Base_GAZ
+    EM,     // E_Modifier
+    EX,     // ExtendNumLet
+    Extend, // Extend
+    FO,     // Format
+    GAZ,    // Glue_After_Zwj
+    HL,     // Hebrew_Letter
+    KA,     // Katakana
+    LE,     // ALetter
+    LF,     // LF
+    MB,     // MidNumLet
+    ML,     // MidLetter
+    MN,     // MidNum
+    NL,     // Newline
+    NU,     // Numeric
+    RI,     // Regional_Indicator
+    SQ,     // Single_Quote
+    WSegSpace,  // WSegSpace
+    XX,     // Other
+    ZWJ,    // ZWJ
+}
+
+impl UnicodeProperty for Wb {
+    fn property_value_name(&self) -> PropertyName {
+        property_names::wb_name(*self)
+    }
+}
