@@ -702,6 +702,10 @@ pub(crate) fn blk_name(prop: Blk) -> PropertyName {
             full: "Arabic_Extended_A",
             abbr: "Arabic_Ext_A",
         },
+        Blk::ArabicExtB => PropertyName {
+            full: "Arabic_Extended_B",
+            abbr: "Arabic_Ext_B",
+        },
         Blk::ArabicMath => PropertyName {
             full: "Arabic_Mathematical_Alphabetic_Symbols",
             abbr: "Arabic_Math",
@@ -926,6 +930,10 @@ pub(crate) fn blk_name(prop: Blk) -> PropertyName {
             full: "Cypriot_Syllabary",
             abbr: "Cypriot_Syllabary",
         },
+        Blk::CyproMinoan => PropertyName {
+            full: "Cypro_Minoan",
+            abbr: "Cypro_Minoan",
+        },
         Blk::Cyrillic => PropertyName {
             full: "Cyrillic",
             abbr: "Cyrillic",
@@ -1046,6 +1054,10 @@ pub(crate) fn blk_name(prop: Blk) -> PropertyName {
             full: "Ethiopic_Extended_A",
             abbr: "Ethiopic_Ext_A",
         },
+        Blk::EthiopicExtB => PropertyName {
+            full: "Ethiopic_Extended_B",
+            abbr: "Ethiopic_Ext_B",
+        },
         Blk::EthiopicSup => PropertyName {
             full: "Ethiopic_Supplement",
             abbr: "Ethiopic_Sup",
@@ -1202,6 +1214,10 @@ pub(crate) fn blk_name(prop: Blk) -> PropertyName {
             full: "Kana_Extended_A",
             abbr: "Kana_Ext_A",
         },
+        Blk::KanaExtB => PropertyName {
+            full: "Kana_Extended_B",
+            abbr: "Kana_Ext_B",
+        },
         Blk::KanaSup => PropertyName {
             full: "Kana_Supplement",
             abbr: "Kana_Sup",
@@ -1286,6 +1302,14 @@ pub(crate) fn blk_name(prop: Blk) -> PropertyName {
             full: "Latin_Extended_E",
             abbr: "Latin_Ext_E",
         },
+        Blk::LatinExtF => PropertyName {
+            full: "Latin_Extended_F",
+            abbr: "Latin_Ext_F",
+        },
+        Blk::LatinExtG => PropertyName {
+            full: "Latin_Extended_G",
+            abbr: "Latin_Ext_G",
+        },
         Blk::Lepcha => PropertyName {
             full: "Lepcha",
             abbr: "Lepcha",
@@ -1550,6 +1574,10 @@ pub(crate) fn blk_name(prop: Blk) -> PropertyName {
             full: "Old_Turkic",
             abbr: "Old_Turkic",
         },
+        Blk::OldUyghur => PropertyName {
+            full: "Old_Uyghur",
+            abbr: "Old_Uyghur",
+        },
         Blk::Oriya => PropertyName {
             full: "Oriya",
             abbr: "Oriya",
@@ -1794,6 +1822,10 @@ pub(crate) fn blk_name(prop: Blk) -> PropertyName {
             full: "Tamil_Supplement",
             abbr: "Tamil_Sup",
         },
+        Blk::Tangsa => PropertyName {
+            full: "Tangsa",
+            abbr: "Tangsa",
+        },
         Blk::Tangut => PropertyName {
             full: "Tangut",
             abbr: "Tangut",
@@ -1830,6 +1862,10 @@ pub(crate) fn blk_name(prop: Blk) -> PropertyName {
             full: "Tirhuta",
             abbr: "Tirhuta",
         },
+        Blk::Toto => PropertyName {
+            full: "Toto",
+            abbr: "Toto",
+        },
         Blk::TransportAndMap => PropertyName {
             full: "Transport_And_Map_Symbols",
             abbr: "Transport_And_Map",
@@ -1842,6 +1878,10 @@ pub(crate) fn blk_name(prop: Blk) -> PropertyName {
             full: "Unified_Canadian_Aboriginal_Syllabics_Extended",
             abbr: "UCAS_Ext",
         },
+        Blk::UcasExtA => PropertyName {
+            full: "Unified_Canadian_Aboriginal_Syllabics_Extended_A",
+            abbr: "UCAS_Ext_A",
+        },
         Blk::Ugaritic => PropertyName {
             full: "Ugaritic",
             abbr: "Ugaritic",
@@ -1858,6 +1898,10 @@ pub(crate) fn blk_name(prop: Blk) -> PropertyName {
             full: "Vertical_Forms",
             abbr: "Vertical_Forms",
         },
+        Blk::Vithkuqi => PropertyName {
+            full: "Vithkuqi",
+            abbr: "Vithkuqi",
+        },
         Blk::Vs => PropertyName {
             full: "Variation_Selectors",
             abbr: "VS",
@@ -1894,6 +1938,10 @@ pub(crate) fn blk_name(prop: Blk) -> PropertyName {
             full: "Zanabazar_Square",
             abbr: "Zanabazar_Square",
         },
+        Blk::ZnamennyMusic => PropertyName {
+            full: "Znamenny_Musical_Notation",
+            abbr: "Znamenny_Music",
+        },
     }
 }
 
@@ -2000,6 +2048,10 @@ pub(crate) fn sc_name(prop: Sc) -> PropertyName {
             full: "Coptic",
             abbr: "Copt",
         },
+        Sc::Cpmn => PropertyName {
+            full: "Cypro_Minoan",
+            abbr: "Cpmn",
+        },
         Sc::Cprt => PropertyName {
             full: "Cypriot",
             abbr: "Cprt",
@@ -2316,6 +2368,10 @@ pub(crate) fn sc_name(prop: Sc) -> PropertyName {
             full: "Osmanya",
             abbr: "Osma",
         },
+        Sc::Ougr => PropertyName {
+            full: "Old_Uyghur",
+            abbr: "Ougr",
+        },
         Sc::Palm => PropertyName {
             full: "Palmyrene",
             abbr: "Palm",
@@ -2484,6 +2540,14 @@ pub(crate) fn sc_name(prop: Sc) -> PropertyName {
             full: "Tirhuta",
             abbr: "Tirh",
         },
+        Sc::Tnsa => PropertyName {
+            full: "Tangsa",
+            abbr: "Tnsa",
+        },
+        Sc::Toto => PropertyName {
+            full: "Toto",
+            abbr: "Toto",
+        },
         Sc::Ugar => PropertyName {
             full: "Ugaritic",
             abbr: "Ugar",
@@ -2492,6 +2556,10 @@ pub(crate) fn sc_name(prop: Sc) -> PropertyName {
             full: "Vai",
             abbr: "Vaii",
         },
+        Sc::Vith => PropertyName {
+            full: "Vithkuqi",
+            abbr: "Vith",
+        },
         Sc::Wara => PropertyName {
             full: "Warang_Citi",
             abbr: "Wara",
@@ -2629,9 +2697,110 @@ pub(crate) fn age_name(prop: Age) -> PropertyName {
             full: "V13_0",
             abbr: "13.0",
         },
+        Age::V14_0 => PropertyName {
+            full: "V14_0",
+            abbr: "14.0",
+        },
         Age::NA => PropertyName {
             full: "Unassigned",
             abbr: "NA",
         },
      }
-}
\ No newline at end of file
+}
+
+pub(crate) fn wb_name(prop: Wb) -> PropertyName {
+    match prop {
+        Wb::CR => PropertyName {
+            full: "CR",
+            abbr: "CR",
+        },
+        Wb::DQ => PropertyName {
+            full: "Double_Quote",
+            abbr: "DQ",
+        },
+        Wb::EB => PropertyName {
+            full: "E_Base",
+            abbr: "EB",
+        },
+        Wb::EBG => PropertyName {
+            full: "E_Base_GAZ",
+            abbr: "EBG",
+        },
+        Wb::EM => PropertyName {
+            full: "E_Modifier",
+            abbr: "EM",
+        },
+        Wb::EX => PropertyName {
+            full: "ExtendNumLet",
+            abbr: "EX",
+        },
+        Wb::Extend => PropertyName {
+            full: "Extend",
+            abbr: "Extend",
+        },
+        Wb::FO => PropertyName {
+            full: "Format",
+            abbr: "FO",
+        },
+        Wb::GAZ => PropertyName {
+            full: "Glue_After_Zwj",
+            abbr: "GAZ",
+        },
+        Wb::HL => PropertyName {
+            full: "Hebrew_Letter",
+            abbr: "HL",
+        },
+        Wb::KA => PropertyName {
+            full: "Katakana",
+            abbr: "KA",
+        },
+        Wb::LE => PropertyName {
+            full: "ALetter",
+            abbr: "LE",
+        },
+        Wb::LF => PropertyName {
+            full: "LF",
+            abbr: "LF",
+        },
+        Wb::MB => PropertyName {
+            full: "MidNumLet",
+            abbr: "MB",
+        },
+        Wb::ML => PropertyName {
+            full: "MidLetter",
+            abbr: "ML",
+        },
+        Wb::MN => PropertyName {
+            full: "MidNum",
+            abbr: "MN",
+        },
+        Wb::NL => PropertyName {
+            full: "Newline",
+            abbr: "NL",
+        },
+        Wb::NU => PropertyName {
+            full: "Numeric",
+            abbr: "NU",
+        },
+        Wb::RI => PropertyName {
+            full: "Regional_Indicator",
+            abbr: "RI",
+        },
+        Wb::SQ => PropertyName {
+            full: "Single_Quote",
+            abbr: "SQ",
+        },
+        Wb::WSegSpace => PropertyName {
+            full: "WSegSpace",
+            abbr: "WSegSpace",
+        },
+        Wb::XX => PropertyName {
+            full: "Other",
+            abbr: "XX",
+        },
+        Wb::ZWJ => PropertyName {
+            full: "ZWJ",
+            abbr: "ZWJ",
+        },
+    }
+}
