@@ -163,7 +163,9 @@ fn check_properties(cp: CodePoint, el: &Vec<OwnedAttribute>) -> bool {
     // nt                       ; Numeric_Type
     // SB                       ; Sentence_Break
     // vo                       ; Vertical_Orientation
-    // WB                       ; Word_Break
+    // WB (Word_Break)
+    let cp_wb = cp.wb().property_value_name().abbr;
+    check_property(cp, cp_wb, "WB", el);
 
     //================================================
     // Binary Properties
@@ -184,7 +186,9 @@ fn check_properties(cp: CodePoint, el: &Vec<OwnedAttribute>) -> bool {
     // CE (Composition_Exclusion)
     let cp_ce = BinaryProperty::from(cp.ce()).property_value_name().abbr;
     check_property(cp, cp_ce, "CE", el);
-    // CI                       ; Case_Ignorable
+    // CI (Case_Ignorable)
+    let cp_ci = BinaryProperty::from(cp.ci()).property_value_name().abbr;
+    check_property(cp, cp_ci, "CI", el);
     // Comp_Ex (Full_Composition_Exclusion)
     let cp_comp_ex = BinaryProperty::from(cp.comp_ex()).property_value_name().abbr;
     check_property(cp, cp_comp_ex, "Comp_Ex", el);
@@ -200,7 +204,9 @@ fn check_properties(cp: CodePoint, el: &Vec<OwnedAttribute>) -> bool {
     // Dep (Deprecated)
     let cp_dep = BinaryProperty::from(cp.dep()).property_value_name().abbr;
     check_property(cp, cp_dep, "Dep", el);
-    // DI                       ; Default_Ignorable_Code_Point
+    // DI (Default_Ignorable_Code_Point)
+    let cp_di = BinaryProperty::from(cp.di()).property_value_name().abbr;
+    check_property(cp, cp_di, "DI", el);
     // Dia (Diacritic)
     let cp_dia = BinaryProperty::from(cp.dia()).property_value_name().abbr;
     check_property(cp, cp_dia, "Dia", el);
@@ -226,7 +232,9 @@ fn check_properties(cp: CodePoint, el: &Vec<OwnedAttribute>) -> bool {
     let cp_ext_pict = BinaryProperty::from(cp.ext_pict()).property_value_name().abbr;
     check_property(cp, cp_ext_pict, "ExtPict", el);
     // Gr_Base                  ; Grapheme_Base
-    // Gr_Ext                   ; Grapheme_Extend
+    // Gr_Ext (Grapheme_Extend)
+    let cp_gr_ext = BinaryProperty::from(cp.gr_ext()).property_value_name().abbr;
+    check_property(cp, cp_gr_ext, "Gr_Ext", el);
     // Gr_Link                  ; Grapheme_Link
     // Hex (Hex_Digit)
     let cp_hex = BinaryProperty::from(cp.hex()).property_value_name().abbr;
