@@ -43,6 +43,9 @@ property_info = {
     'age': {
         'repr_size': 1,
     },
+    'wb': {
+        'repr_size': 1,
+    },
 }
 
 
@@ -428,4 +431,11 @@ if __name__ == '__main__':
         f.write(dm_map_rs())
     # Make CE data.
     with open('../../src/unicode/ucd/ce.rs', 'w') as f:
-        f.write(ce_rs())
\ No newline at end of file
+        f.write(ce_rs())
+    # Make WB data.
+    wb_data = make_data('auxiliary/WordBreakProperty.json')
+    wb_data = data_value_as_abbr(wb_data, 'WB')
+    tst = select_minimal_tst('Wb', wb_data, property_info['wb']['repr_size'],
+        default_prop='XX')
+    with open('../../src/unicode/ucd/wb.rs', 'w') as f:
+        f.write(tst.to_seshat())
